# CodeSee Utilities

A collection of Python utilities devloped by
[CodeSee](https://www.codesee.io). Includes the following:

## codesee-py

A command-line utility we use when generating CodeSee Maps. It
has the ability to introspect a directory containing a Python package,
and emits information about that package.
